@@ -530,7 +530,7 @@ EOS
 
 			def parse_operator
 				o = @scanner.matched
-				Operator.new << o
+				Operator.new.tap{|op| op[:stretchy]="false"} << o
 			end
 
 			def parse_block
@@ -614,6 +614,7 @@ EOS
 					el.extend(Variant).variant = Variant::NORMAL unless s.is_a?(String)&&s.length>1
 				when :o
 					el = Operator.new
+					el[:stretchy] = "false"
 				when :n
 					el = Number.new
 				else
@@ -702,7 +703,7 @@ EOS
 
 		module BuiltinCommands
 			OVERS = {'hat'=>'circ', 'breve'=>'smile', 'grave'=>'grave',
-				'acute'=>'acute', 'dot'=>'sdot', 'ddot'=>'nldr', 'tilde'=>'tilde',
+				'acute'=>'acute', 'dot'=>'sdot', 'ddot'=>'nldr', 'dddot'=>'mldr', 'tilde'=>'tilde',
 				'bar'=>'macr', 'vec'=>'rightarrow', 'check'=>'vee', 'widehat'=>'circ',
 				'overline'=>'macr', 'widetilde'=>'tilde', 'overbrace'=>'OverBrace'}
 			UNDERS = {'underbrace'=>'UnderBrace', 'underline'=>'macr'}
@@ -710,8 +711,8 @@ EOS
 			def initialize
 				add_commands("\\"=>:backslash)
 				add_commands("entity", "stackrel", "frac", "sqrt", "mbox")
-				add_multi_command(:hat_etc, 'hat', 'breve', 'grave', 'acute', 'dot', 'ddot', 'tilde', 'bar', 'vec', 'check', 'widehat', 'overline', 'widetilde', 'overbrace')
-				add_multi_command(:underbrace_etc, 'underbrace', 'underline')
+				add_multi_command(:hat_etc, *OVERS.keys)
+				add_multi_command(:underbrace_etc, *UNDERS.keys)
 				add_multi_command(:quad_etc, " ", "quad", "qquad", ",", ":", ";", "!")
 				add_multi_command(:it_etc, "it", "rm", "bf")
 				add_multi_command(:mathit_etc, "mathit", "mathrm", "mathbf", "bm", "mathbb", "mathscr", "mathfrak")
